@@ -95,6 +95,26 @@ sub _perl {
             $h->{version} = $version if $version;
         }
     }
+    elsif ( index($d->ua, 'SOAP::Lite/Perl/') > -1 ) {
+        $h = {
+            name => 'SOAP::Lite Perl',
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!^SOAP::Lite/Perl/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+    }
+    elsif ( index($d->ua, 'MT::Plugin::BadLinkFinder/') > -1 ) {
+        $h = {
+            name => 'MT::Plugin::BadLinkFinder',
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!^MT::Plugin::BadLinkFinder/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+    }
 
     return $h;
 }
@@ -144,6 +164,16 @@ sub _python {
             $h->{version} = $version if $version;
         }
     }
+    elsif ( index($d->ua, 'python-requests/') > -1 ) {
+        $h = {
+            name => 'python-requests',
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!^python-requests/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+    }
 
     return $h;
 }
@@ -183,6 +213,11 @@ sub _php {
             $h->{version} = $version if $version;
         }
     }
+    elsif ( $d->ua eq 'Zend_XmlRpc_Client' ) {
+        $h = {
+            name => 'Zend_XmlRpc_Client',
+        };
+    }
 
     return $h;
 }
@@ -259,6 +294,18 @@ sub _golang {
             $h->{version} = $version if $version;
         }
 
+        return $h;
+    }
+    elsif ( index($d->ua, 'Go ') > -1 && index($d->ua, ' package http') > -1 ) {
+        my $h = {
+            name => 'Go http-client',
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!^Go ([\d.]+) !);
+            $h->{version} = $version if $version;
+        }
+
         return $h;
     }
 }
